.. _tutorial_fsl:

==========================
Using FSL for DTI analysis
==========================

This tutorial illustrates how to perform a dti analysis with
FSL_.

In order to run this tutorial you need to have fsl tools installed and
accessible from matlab/command line. Check by calling fslinfo from the
command line. 

.. include:: ../examples/fsl_dti_tutorial.rst

.. include:: ../links_names.txt
